## APIs

There are multiple APIs that support TCB multiple capabilities.

- [Core FastAPI](docs/dev/apis#core-fastapi)
- [Athena API  ](docs/dev/apis#athena-api  ) - [open directly](/api/docs     )
- [Markdown API](docs/dev/apis#markdown-api) - [open directly](/markdown/docs)
- [LLMs API    ](docs/dev/apis#llms-api)
- [ODIN - Chat ](docs/dev/apis#odin-chat)
- [ODIN - API  ](docs/dev/apis#odin-api)


### Core FastAPI
<a id="core-fastapi"></a>
{{iframe:/docs }}

---- 
### Athena API
<a id="athena-api"></a>
{{iframe:/api/docs }}

---- 
### Markdown API 
<a id="markdown-api"></a>
{{iframe:/markdown/docs }}

---- 
### LLMs API
<a id="llms-api"></a>
{{iframe:/api/llms/docs }}

---- 
### ODIN - Chat
<a id="odin-chat"></a>
{{iframe:/api/odin/chat/docs}}

---- 
### ODIN - API
<a id="odin-api"></a>
{{iframe:/api/odin/api/docs }}
